<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import dayjs from 'dayjs'
import 'dayjs/locale/zh-cn'
export default {
  data() {
    const defaultDate = `${dayjs().format('YYYY-MM-DD')} 00:00:00`
    return {
      tableConfig: {
        url: 'flower/v2/sms-template/list',
        newUrl: 'flower/v2/sms-template/new',
        deleteUrl: 'flower/v2/sms-template/delete',
        editUrl: 'flower/v2/sms-template/edit',
        columns: [
          { label: 'ID', prop: 'id' },
          { label: 'CODE', prop: 'code' },
          { label: '模板名称', prop: 'name' },
          { label: '模板描述', prop: 'description' },
          { label: '创建时间', prop: 'createTime' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              { label: 'ID', id: 'id', type: 'input' },
              { label: 'CODE', id: 'code', type: 'input' },
              { label: '模板名称', id: 'name', type: 'input' },
              {
                label: '创建时间',
                id: 'startDate',
                component: 'el-bus-date-range',
                el: {
                  clearable: true,
                },
                // commonFormat: true,
                commonFormatProps: ['startDate', 'endDate'],
                inputFormat: (row) => {
                  if ('startDate' in row || 'endDate' in row) {
                    return [
                      this.$elBusUtil.toDate(row.startDate),
                      this.$elBusUtil.toDate(row.endDate),
                    ]
                  }
                },
                outputFormat: (val) => {
                  return {
                    startDate:val[0] ? `${this.$elBusUtil.toDate(val[0])} 00:00:00`: undefined,
                    endDate: val[1] ?`${this.$elBusUtil.toDate(val[1])} 23:59:59`: undefined,
                  }
                },
                customClass: 'in-bus-form',
                // commonRules: true,
                // default: [defaultDate, defaultDate],
              },
            ],
          },
        ],
        form: [
          {
            label: 'CODE：',
            id: 'code',
            type: 'bus-select',
            el: {
              interfaceUri: 'flower/v2/sms-template/aliyun/list',
              extraQuery: {
                current: 1,
                size: 2000,
              },
              props: {
                label: 'templateName',
                value: 'templateCode',
                // dataPath: 'records',
              },
              filterable: true,
              multiple: false,
              style: 'width:100%',
            },
            rules: {
              required: true,
              message: '请选择CODE',
              trigger: 'blur',
            },
          },

          {
            label: '模板名称：',
            id: 'name',
            type: 'input',
            rules: {
              required: true,
              message: '请输入模板名称',
              trigger: 'blur',
            },
          },
          {
            label: '模板描述：',
            id: 'description',
            type: 'input',
            el: {
              type: 'textarea',
              rows: 6,
            },
            rules: {
              required: true,
              message: '请输入模板描述',
              trigger: 'blur',
            },
          },
          
        ],
      },
    }
  },
  head() {
    return {
      title: '短信模板维护',
    }
  },
}
</script>
